#[repr(u32)]pub enum MavFrame {
Show 22 variants
MAV_FRAME_GLOBAL = 0,
MAV_FRAME_LOCAL_NED = 1,
MAV_FRAME_MISSION = 2,
MAV_FRAME_GLOBAL_RELATIVE_ALT = 3,
MAV_FRAME_LOCAL_ENU = 4,
MAV_FRAME_GLOBAL_INT = 5,
MAV_FRAME_GLOBAL_RELATIVE_ALT_INT = 6,
MAV_FRAME_LOCAL_OFFSET_NED = 7,
MAV_FRAME_BODY_NED = 8,
MAV_FRAME_BODY_OFFSET_NED = 9,
MAV_FRAME_GLOBAL_TERRAIN_ALT = 10,
MAV_FRAME_GLOBAL_TERRAIN_ALT_INT = 11,
MAV_FRAME_BODY_FRD = 12,
MAV_FRAME_RESERVED_13 = 13,
MAV_FRAME_RESERVED_14 = 14,
MAV_FRAME_RESERVED_15 = 15,
MAV_FRAME_RESERVED_16 = 16,
MAV_FRAME_RESERVED_17 = 17,
MAV_FRAME_RESERVED_18 = 18,
MAV_FRAME_RESERVED_19 = 19,
MAV_FRAME_LOCAL_FRD = 20,
MAV_FRAME_LOCAL_FLU = 21,
}dialect-uavionix only.Expand description
Coordinate frames used by MAVLink. Not all frames are supported by all commands, messages, or vehicles. Global frames use the following naming conventions: - “GLOBAL”: Global coordinate frame with WGS84 latitude/longitude and altitude positive over mean sea level (MSL) by default. The following modifiers may be used with “GLOBAL”: - “RELATIVE_ALT”: Altitude is relative to the vehicle home position rather than MSL. - “TERRAIN_ALT”: Altitude is relative to ground level rather than MSL. - “INT”: Latitude/longitude (in degrees) are scaled by multiplying by 1E7. Local frames use the following naming conventions: - “LOCAL”: Origin of local frame is fixed relative to earth. Unless otherwise specified this origin is the origin of the vehicle position-estimator (“EKF”). - “BODY”: Origin of local frame travels with the vehicle. NOTE, “BODY” does NOT indicate alignment of frame axis with vehicle attitude. - “OFFSET”: Deprecated synonym for “BODY” (origin travels with the vehicle). Not to be used for new frames. Some deprecated frames do not follow these conventions (e.g. MAV_FRAME_BODY_NED and MAV_FRAME_BODY_OFFSET_NED).
Variants
MAV_FRAME_GLOBAL = 0
Global (WGS84) coordinate frame + altitude relative to mean sea level (MSL).
MAV_FRAME_LOCAL_NED = 1
NED local tangent frame (x: North, y: East, z: Down) with origin fixed relative to earth.
MAV_FRAME_MISSION = 2
NOT a coordinate frame, indicates a mission command.
MAV_FRAME_GLOBAL_RELATIVE_ALT = 3
Global (WGS84) coordinate frame + altitude relative to the home position.
MAV_FRAME_LOCAL_ENU = 4
ENU local tangent frame (x: East, y: North, z: Up) with origin fixed relative to earth.
MAV_FRAME_GLOBAL_INT = 5
MAV_FRAME_GLOBAL (Superseded since 2024-03)Global (WGS84) coordinate frame (scaled) + altitude relative to mean sea level (MSL).
MAV_FRAME_GLOBAL_RELATIVE_ALT_INT = 6
MAV_FRAME_GLOBAL_RELATIVE_ALT (Superseded since 2024-03)Global (WGS84) coordinate frame (scaled) + altitude relative to the home position.
MAV_FRAME_LOCAL_OFFSET_NED = 7
NED local tangent frame (x: North, y: East, z: Down) with origin that travels with the vehicle.
MAV_FRAME_BODY_NED = 8
MAV_FRAME_BODY_FRD (Superseded since 2019-08)Same as MAV_FRAME_LOCAL_NED when used to represent position values. Same as MAV_FRAME_BODY_FRD when used with velocity/acceleration values.
MAV_FRAME_BODY_OFFSET_NED = 9
MAV_FRAME_BODY_FRD (Superseded since 2019-08)This is the same as MAV_FRAME_BODY_FRD.
MAV_FRAME_GLOBAL_TERRAIN_ALT = 10
Global (WGS84) coordinate frame with AGL altitude (altitude at ground level).
MAV_FRAME_GLOBAL_TERRAIN_ALT_INT = 11
MAV_FRAME_GLOBAL_TERRAIN_ALT (Superseded since 2024-03)Global (WGS84) coordinate frame (scaled) with AGL altitude (altitude at ground level).
MAV_FRAME_BODY_FRD = 12
FRD local frame aligned to the vehicle’s attitude (x: Forward, y: Right, z: Down) with an origin that travels with vehicle.
MAV_FRAME_RESERVED_13 = 13
MAV_FRAME_BODY_FLU - Body fixed frame of reference, Z-up (x: Forward, y: Left, z: Up).
MAV_FRAME_RESERVED_14 = 14
MAV_FRAME_LOCAL_FRD (Deprecated since 2019-04)MAV_FRAME_MOCAP_NED - Odometry local coordinate frame of data given by a motion capture system, Z-down (x: North, y: East, z: Down).
MAV_FRAME_RESERVED_15 = 15
MAV_FRAME_LOCAL_FLU (Deprecated since 2019-04)MAV_FRAME_MOCAP_ENU - Odometry local coordinate frame of data given by a motion capture system, Z-up (x: East, y: North, z: Up).
MAV_FRAME_RESERVED_16 = 16
MAV_FRAME_LOCAL_FRD (Deprecated since 2019-04)MAV_FRAME_VISION_NED - Odometry local coordinate frame of data given by a vision estimation system, Z-down (x: North, y: East, z: Down).
MAV_FRAME_RESERVED_17 = 17
MAV_FRAME_LOCAL_FLU (Deprecated since 2019-04)MAV_FRAME_VISION_ENU - Odometry local coordinate frame of data given by a vision estimation system, Z-up (x: East, y: North, z: Up).
MAV_FRAME_RESERVED_18 = 18
MAV_FRAME_LOCAL_FRD (Deprecated since 2019-04)MAV_FRAME_ESTIM_NED - Odometry local coordinate frame of data given by an estimator running onboard the vehicle, Z-down (x: North, y: East, z: Down).
MAV_FRAME_RESERVED_19 = 19
MAV_FRAME_LOCAL_FLU (Deprecated since 2019-04)MAV_FRAME_ESTIM_ENU - Odometry local coordinate frame of data given by an estimator running onboard the vehicle, Z-up (x: East, y: North, z: Up).
MAV_FRAME_LOCAL_FRD = 20
FRD local tangent frame (x: Forward, y: Right, z: Down) with origin fixed relative to earth. The forward axis is aligned to the front of the vehicle in the horizontal plane.
MAV_FRAME_LOCAL_FLU = 21
FLU local tangent frame (x: Forward, y: Left, z: Up) with origin fixed relative to earth. The forward axis is aligned to the front of the vehicle in the horizontal plane.
Implementations