pub struct GIMBAL_DEVICE_INFORMATION_DATA {Show 16 fields
pub uid: u64,
pub time_boot_ms: u32,
pub firmware_version: u32,
pub hardware_version: u32,
pub roll_min: f32,
pub roll_max: f32,
pub pitch_min: f32,
pub pitch_max: f32,
pub yaw_min: f32,
pub yaw_max: f32,
pub cap_flags: GimbalDeviceCapFlags,
pub custom_cap_flags: u16,
pub vendor_name: CharArray<32>,
pub model_name: CharArray<32>,
pub custom_name: CharArray<32>,
pub gimbal_device_id: u8,
}dialect-uavionix only.Expand description
Information about a low level gimbal. This message should be requested by the gimbal manager or a ground station using MAV_CMD_REQUEST_MESSAGE. The maximum angles and rates are the limits by hardware. However, the limits by software used are likely different/smaller and dependent on mode/settings/etc..
ID: 283
Fields
uid: u64UID of gimbal hardware (0 if unknown).
time_boot_ms: u32Timestamp (time since system boot).
firmware_version: u32Version of the gimbal firmware, encoded as: (Dev&0xff)<<24 + (Patch&0xff)<<16 + (Minor&0xff)<<8 + (Major&0xff).
hardware_version: u32Version of the gimbal hardware, encoded as: (Dev&0xff)<<24 + (Patch&0xff)<<16 + (Minor&0xff)<<8 + (Major&0xff).
roll_min: f32Minimum hardware roll angle (positive: rolling to the right, negative: rolling to the left). NAN if unknown.
roll_max: f32Maximum hardware roll angle (positive: rolling to the right, negative: rolling to the left). NAN if unknown.
pitch_min: f32Minimum hardware pitch angle (positive: up, negative: down). NAN if unknown.
pitch_max: f32Maximum hardware pitch angle (positive: up, negative: down). NAN if unknown.
yaw_min: f32Minimum hardware yaw angle (positive: to the right, negative: to the left). NAN if unknown.
yaw_max: f32Maximum hardware yaw angle (positive: to the right, negative: to the left). NAN if unknown.
cap_flags: GimbalDeviceCapFlagsBitmap of gimbal capability flags.
custom_cap_flags: u16Bitmap for use for gimbal-specific capability flags.
vendor_name: CharArray<32>Name of the gimbal vendor.
model_name: CharArray<32>Name of the gimbal model.
custom_name: CharArray<32>Custom name of the gimbal given to it by the user.
gimbal_device_id: u8This field is to be used if the gimbal manager and the gimbal device are the same component and hence have the same component ID. This field is then set to a number between 1-6. If the component ID is separate, this field is not required and must be set to 0.
Implementations