pub struct HIL_GPS_DATA {}dialect-uavionix only.Expand description
The global position, as returned by the Global Positioning System (GPS). This is NOT the global position estimate of the system, but rather a RAW sensor value. See message GLOBAL_POSITION_INT for the global position estimate.
ID: 113
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
lat: i32Latitude (WGS84)
lon: i32Longitude (WGS84)
alt: i32Altitude (MSL). Positive for up.
eph: u16GPS HDOP horizontal dilution of position (unitless * 100). If unknown, set to: UINT16_MAX
epv: u16GPS VDOP vertical dilution of position (unitless * 100). If unknown, set to: UINT16_MAX
vel: u16GPS ground speed. If unknown, set to: UINT16_MAX
vn: i16GPS velocity in north direction in earth-fixed NED frame
ve: i16GPS velocity in east direction in earth-fixed NED frame
vd: i16GPS velocity in down direction in earth-fixed NED frame
cog: u16Course over ground (NOT heading, but direction of movement), 0.0..359.99 degrees. If unknown, set to: UINT16_MAX
fix_type: u80-1: no fix, 2: 2D fix, 3: 3D fix. Some applications will not use the value of this field unless it is at least two, so always correctly fill in the fix.
satellites_visible: u8Number of satellites visible. If unknown, set to UINT8_MAX
id: u8GPS ID (zero indexed). Used for multiple GPS inputs
yaw: u16Yaw of vehicle relative to Earth’s North, zero means not available, use 36000 for north
Implementations